@@ -47,11 +47,9 @@
 #include <string.h> /* for strdup */
 #include <limits.h> /* for INT_MAX */
 
-#ifdef WIN32
-#define strncasecmp      strnicmp
-#ifndef HAVE_SNPRINTF
-#include "vsnprintf.h"
-#endif
+#ifdef _MSC_VER
+#define snprintf _snprintf
+#define strncasecmp strnicmp
 #endif
 
 struct icalcomponent_impl 
@@ -88,7 +86,7 @@ static void icalcomponent_handle_conflicting_vtimezones (icalcomponent *comp,
 							 icalproperty *tzid_prop,
 							 const char *tzid,
 							 icalarray *tzids_to_rename);
-static unsigned int icalcomponent_get_tzid_prefix_len (const char *tzid);
+static size_t icalcomponent_get_tzid_prefix_len (const char *tzid);
 static void icalcomponent_rename_tzids(icalcomponent* comp,
 				       icalarray* rename_table);
 static void icalcomponent_rename_tzids_callback(icalparameter *param,
@@ -492,7 +490,7 @@ icalproperty* icalcomponent_get_current_property (icalcomponent* component)
 {
    icalerror_check_arg_rz( (component!=0),"component");
 
-   if ((component->property_iterator==0)){
+   if (component->property_iterator==0){
        return 0;
    }
 
@@ -1003,7 +1001,7 @@ void icalcomponent_foreach_recurrence(icalcomponent* comp,
   struct icaltimetype dtstart, dtend;
   icaltime_span recurspan, basespan, limit_span;
   time_t limit_start, limit_end;
-  int dtduration;
+  time_t dtduration;
   icalproperty *rrule, *rdate;
   struct icaldurationtype dur;
   pvl_elem property_iterator;	/* for saving the iterator */
@@ -1637,17 +1635,20 @@ struct icaltimetype icalcomponent_get_dtend(icalcomponent* comp)
     struct icaltimetype	ret = icaltime_null_time();
 
     if ( end_prop != 0) {
-	ret = icalcomponent_get_datetime(comp, end_prop);
-    } else if ( dur_prop != 0) { 
+        ret = icalcomponent_get_datetime(comp, end_prop);
+    } else if ( dur_prop != 0) {
 
-	struct icaltimetype start = 
-	    icalcomponent_get_dtstart(inner);
-	struct icaldurationtype duration = 
-	    icalproperty_get_duration(dur_prop);
+        struct icaltimetype start = icalcomponent_get_dtstart(inner);
+        struct icaldurationtype duration;
+        
+        //extra check to prevent empty durations from crashing
+        if (icalproperty_get_value(dur_prop)) {
+            duration = icalproperty_get_duration(dur_prop);
+        } else {
+            duration = icaldurationtype_null_duration();
+        }
 
-	struct icaltimetype end = icaltime_add(start,duration);
-
-	ret = end;
+        ret = icaltime_add(start,duration);
     }
 
     return ret;
@@ -2234,7 +2235,7 @@ icalcomponent_handle_conflicting_vtimezones (icalcomponent *comp,
 					     icalarray *tzids_to_rename)
 {
   int i, suffix, max_suffix = 0, num_elements;
-  unsigned int tzid_len;
+  size_t tzid_len;
   char *tzid_copy, *new_tzid, suffix_buf[32];
   (void)tzid_prop; /* hack to stop unused variable warning */
 
@@ -2253,7 +2254,7 @@ icalcomponent_handle_conflicting_vtimezones (icalcomponent *comp,
     icaltimezone *zone;
     const char *existing_tzid;
     const char *existing_tzid_copy;
-    unsigned int existing_tzid_len;
+    size_t existing_tzid_len;
 
     zone = icalarray_element_at (comp->timezones, i);
     existing_tzid = icaltimezone_get_tzid (zone);
@@ -2322,9 +2323,9 @@ icalcomponent_handle_conflicting_vtimezones (icalcomponent *comp,
 
 
 /* Returns the length of the TZID, without any trailing digits. */
-static unsigned int icalcomponent_get_tzid_prefix_len (const char *tzid)
+static size_t icalcomponent_get_tzid_prefix_len (const char *tzid)
 {
-  int len;
+  size_t len;
   const char *p;
 
   len = strlen (tzid);
