@@ -38,9 +38,9 @@
 #include "dmalloc.h"
 #endif
 
-#ifdef WIN32
-#define snprintf      _snprintf
-#define strcasecmp    stricmp
+#if defined(_MSC_VER)
+#define snprintf _snprintf
+#define strcasecmp stricmp
 #endif
 
 /* These *_part routines are called by the MIME parser via the
@@ -53,7 +53,7 @@ struct text_part
 	size_t buf_size;
 };
 
-void* icalmime_text_new_part()
+void* icalmime_text_new_part(void)
 {
 
 #define BUF_SIZE 2048
@@ -97,18 +97,26 @@ void* icalmime_textcalendar_end_part(void* part)
 
 }
 
-void* icalmime_text_end_part(void* part)
+void* icalmime_text_end_part_r(void* part)
 {
     char *buf;
     struct text_part* impl = ( struct text_part*) part;
 
-    icalmemory_add_tmp_buffer(impl->buf);
     buf = impl->buf;
     free(impl);
 
     return buf;
 }
 
+void* icalmime_text_end_part(void* part)
+{
+	void *buf;
+	buf = icalmime_text_end_part_r(part);
+	icalmemory_add_tmp_buffer(buf);
+	return buf;
+}
+
+
 void icalmime_text_free_part(void *part)
 {
     part = part;
@@ -117,7 +125,7 @@ void icalmime_text_free_part(void *part)
 
 /* Ignore Attachments for now */
 
-void* icalmime_attachment_new_part()
+void* icalmime_attachment_new_part(void)
 {
     return 0;
 }
@@ -147,8 +155,8 @@ void icalmime_attachment_free_part(void *part)
 static const struct sspm_action_map icalmime_local_action_map[] = 
 {
     {SSPM_TEXT_MAJOR_TYPE,SSPM_CALENDAR_MINOR_TYPE,icalmime_text_new_part,icalmime_text_add_line,icalmime_textcalendar_end_part,icalmime_text_free_part},
-    {SSPM_TEXT_MAJOR_TYPE,SSPM_ANY_MINOR_TYPE,icalmime_text_new_part,icalmime_text_add_line,icalmime_text_end_part,icalmime_text_free_part},
-    {SSPM_TEXT_MAJOR_TYPE,SSPM_PLAIN_MINOR_TYPE,icalmime_text_new_part,icalmime_text_add_line,icalmime_text_end_part,icalmime_text_free_part},
+    {SSPM_TEXT_MAJOR_TYPE,SSPM_ANY_MINOR_TYPE,icalmime_text_new_part,icalmime_text_add_line,icalmime_text_end_part_r,icalmime_text_free_part},
+    {SSPM_TEXT_MAJOR_TYPE,SSPM_PLAIN_MINOR_TYPE,icalmime_text_new_part,icalmime_text_add_line,icalmime_text_end_part_r,icalmime_text_free_part},
     {SSPM_APPLICATION_MAJOR_TYPE,SSPM_CALENDAR_MINOR_TYPE,icalmime_attachment_new_part,icalmime_attachment_add_line,icalmime_attachment_end_part,icalmime_attachment_free_part},
     {SSPM_IMAGE_MAJOR_TYPE,SSPM_CALENDAR_MINOR_TYPE,icalmime_attachment_new_part,icalmime_attachment_add_line,icalmime_attachment_end_part,icalmime_attachment_free_part},
     {SSPM_AUDIO_MAJOR_TYPE,SSPM_CALENDAR_MINOR_TYPE,icalmime_attachment_new_part,icalmime_attachment_add_line,icalmime_attachment_end_part,icalmime_attachment_free_part},
@@ -182,7 +190,7 @@ icalcomponent* icalmime_parse(char* (*get_string)(char *s, size_t size,
 	return 0;
     }
 
-    memset(parts,0,sizeof(parts));
+    memset(parts,0,sizeof(NUM_PARTS*sizeof(struct sspm_part)));
 
     sspm_parse_mime(parts, 
 		    NUM_PARTS, /* Max parts */
@@ -333,14 +341,11 @@ line between the header and the previous boundary\?";
 	    parent = last;
 	    icalcomponent_add_component(parent,comp);
 
-	    last_level = parts[i].level;
-
 	} else if (parts[i].level < last_level){
 
-	    parent = icalcomponent_get_parent(parent);
+	    if (parent) 
+	        parent = icalcomponent_get_parent(parent);
 	    icalcomponent_add_component(parent,comp);
-
-	    last_level = parts[i].level;
 	} else { 
 	    assert(0);
 	}
@@ -371,7 +376,7 @@ int icalmime_test(char* (*get_string)(char *s, size_t size, void *d),
 	return 0;
     }
 
-    memset(parts,0,sizeof(parts));
+    memset(parts,0,sizeof(NUM_PARTS*sizeof(struct sspm_part)));
 
     sspm_parse_mime(parts, 
 		    NUM_PARTS, /* Max parts */
@@ -383,14 +388,15 @@ int icalmime_test(char* (*get_string)(char *s, size_t size, void *d),
    for(i = 0; i <NUM_PARTS && parts[i].header.major != SSPM_NO_MAJOR_TYPE ; 
        i++){
        if(parts[i].header.minor == SSPM_CALENDAR_MINOR_TYPE){
-	   parts[i].data = icalmemory_strdup(
-	       icalcomponent_as_ical_string((icalcomponent*)parts[i].data));
+	   parts[i].data =
+	       icalcomponent_as_ical_string_r((icalcomponent*)parts[i].data);
        }
    }
 
     sspm_write_mime(parts,NUM_PARTS,&out,"To: bob@bob.org");
 
     printf("%s\n",out);
+    free(out);
 
     return 0;
 
