@@ -139,12 +139,12 @@
 #include <stdint.h>
 #endif
 
-#ifdef WIN32
-#ifndef HAVE_SNPRINTF
-#include "vsnprintf.h"
-#endif
-#endif
+#include <stdio.h>
+#include <stdarg.h>
 
+#if defined(_MSC_VER)
+#define snprintf _snprintf
+#endif
 
 #include <limits.h>
 
@@ -154,8 +154,8 @@ typedef long intptr_t;
 #endif
 #endif
 
-#ifdef WIN32
-#define strcasecmp      stricmp
+#ifdef _MSC_VER
+#define strcasecmp stricmp
 #endif
 
 #include "icalrecur.h"
@@ -163,7 +163,7 @@ typedef long intptr_t;
 #include "icalerror.h"
 #include "icalmemory.h"
 
-#include <stdlib.h> /* for malloc */
+#include <stdlib.h> /* for malloc, strtol */
 #include <errno.h> /* for errno */
 #include <string.h> /* for strdup and strchr*/
 #include <assert.h>
@@ -396,7 +396,7 @@ void icalrecur_add_bydayrules(struct icalrecur_parser *parser, const char* vals)
 	}
 
 	/* Get Optional weekno */
-	weekno = strtol(t,&t,10);
+	weekno = (char)strtol(t,&t,10);
 
 	/* Outlook/Exchange generate "BYDAY=MO, FR" and "BYDAY=2 TH".
 	 * Cope with that.
@@ -1001,13 +1001,14 @@ icalrecur_iterator* icalrecur_iterator_new(struct icalrecurrencetype rule,
         struct icaltimetype next;
 	icalerror_clear_errno();
 
-	for (;;) {
+        /* Fail after hitting the year 20000 if no expanded days match */
+	while (impl->last.year < 20000) {
             expand_year_days(impl, impl->last.year);
-        if( icalerrno != ICAL_NO_ERROR) {
-            icalerror_set_errno(ICAL_MALFORMEDDATA_ERROR);
-            free(impl);
-            return 0;
-        }
+            if( icalerrno != ICAL_NO_ERROR) {
+                icalerror_set_errno(ICAL_MALFORMEDDATA_ERROR);
+                free(impl);
+                return 0;
+            }
 	    if (impl->days[0] != ICAL_RECURRENCE_ARRAY_MAX)
 	        break; /* break when no days are expanded */
 	    increment_year(impl,impl->rule.interval);
@@ -1605,11 +1606,13 @@ static int next_month(icalrecur_iterator* impl)
       int day;
       int days_in_month = icaltime_days_in_month(impl->last.month,
                                                    impl->last.year);
-      assert( BYDAYPTR[0]!=ICAL_RECURRENCE_ARRAY_MAX);
-
       int set_pos_counter = 0;
       int set_pos_total = 0;
-      
+
+      int found = 0;
+
+      assert( BYDAYPTR[0]!=ICAL_RECURRENCE_ARRAY_MAX);
+     
       /* Count the past positions for the BYSETPOS calculation */
       if(has_by_data(impl,BY_SET_POS)){
           int last_day = impl->last.day;
@@ -1624,9 +1627,7 @@ static int next_month(icalrecur_iterator* impl)
 	  }
           impl->last.day = last_day;
       }
-
-      int found = 0;
-      
+     
       for(day = impl->last.day+1; day <= days_in_month; day++){
           impl->last.day = day;
 	  
@@ -1939,8 +1940,8 @@ static int expand_year_days(icalrecur_iterator* impl, int year)
     /* BY_WEEK_NO together with BY_MONTH - may conflict, in this case BY_MONTH wins */
     if( (flags & 1<<BY_MONTH) && (flags & 1<<BY_WEEK_NO) ){
         int valid_weeks[ICAL_BY_WEEKNO_SIZE];
-        memset(valid_weeks, 0, sizeof(valid_weeks));
         int valid = 1;    
+        memset(valid_weeks, 0, sizeof(valid_weeks));
         t.year = year;
         t.is_date = 1;
 
