@@ -47,9 +47,11 @@
 
 #ifdef WIN32
 #include <windows.h>
+#endif
 
-#define snprintf      _snprintf
-#define strcasecmp    stricmp
+#if defined(_MSC_VER)
+#define snprintf   _snprintf
+#define strcasecmp stricmp
 #endif
 
 #ifdef WIN32
@@ -508,7 +510,7 @@ struct icaltimetype icaltime_normalize(const struct icaltimetype tt)
 struct icaltimetype icaltime_from_string(const char* str)
 {
     struct icaltimetype tt = icaltime_null_time();
-    int size;
+    size_t size;
 
     icalerror_check_arg_re(str!=0,"str",icaltime_null_time());
 
