@@ -156,6 +156,7 @@ icalproperty* icalclassify_find_attendee(icalcomponent *c,
 	 this_upn = strchr(this_attendee,':');
 
         if(this_upn == 0){
+	    free(this_attendee);
             continue;
         } else {
             this_upn++;
@@ -475,10 +476,11 @@ int icalclassify_request_new_organizer(
     icalclassify_pre
     icalerror_set_errno(ICAL_UNIMPLEMENTED_ERROR);
     icalclassify_post
+/* already done before.
     (void)comp;
     (void)match;
     (void)user;
-
+*/
 }
 
 int icalclassify_request_status(
@@ -489,9 +491,11 @@ int icalclassify_request_status(
     icalclassify_pre
     icalerror_set_errno(ICAL_UNIMPLEMENTED_ERROR);
     icalclassify_post
+/*
     (void)comp;
     (void)match;
     (void)user;
+*/
 }
 
 int icalclassify_request_forward(
@@ -502,9 +506,11 @@ int icalclassify_request_forward(
     icalclassify_pre
     icalerror_set_errno(ICAL_UNIMPLEMENTED_ERROR);
     icalclassify_post
+/*
     (void)comp;
     (void)match;
     (void)user;
+*/
 }
 
 int icalclassify_request_freebusy(
@@ -515,9 +521,11 @@ int icalclassify_request_freebusy(
     icalclassify_pre
     icalerror_set_errno(ICAL_UNIMPLEMENTED_ERROR);
     icalclassify_post
+/*
     (void)comp;
     (void)match;
     (void)user;
+*/
 }
 
 int icalclassify_reply_accept(
