@@ -45,6 +45,7 @@ int main(int argc, char **argv)
         struct icaltimetype curr_tt;
         int failed = 0;
         int curr_failed;
+        int zonedef_printed = 0;
 
         /*
          * select this location for glibc: needs support for TZ=<location>
@@ -96,13 +97,23 @@ int main(int argc, char **argv)
 
             /* only print first failed day and first day which is okay again */
             if (verbose || curr_failed != failed) {
-                printf("%s: day %03d: %s: libc %04d-%02d-%02d %02d:%02d:%02d dst %d",
+                struct tm utc_tm;
+                gmtime_r(&curr_time, &utc_tm);
+                printf("%s: day %03d: %s: %04d-%02d-%02d %02d:%02d:%02d UTC = libc %04d-%02d-%02d %02d:%02d:%02d dst %d",
                        zone_location,
                        day,
+
                        verbose ?
                        (curr_failed ? "failed" : "okay") :
                        (curr_failed ? "first failed" : "okay again"),
 
+                       utc_tm.tm_year + 1900,
+                       utc_tm.tm_mon + 1,
+                       utc_tm.tm_mday,
+                       utc_tm.tm_hour,
+                       utc_tm.tm_min,
+                       utc_tm.tm_sec,
+
                        curr_tm.tm_year + 1900,
                        curr_tm.tm_mon + 1,
                        curr_tm.tm_mday,
@@ -123,6 +134,14 @@ int main(int argc, char **argv)
                 }
                 printf("\n");
                 failed = curr_failed;
+
+                if (!zonedef_printed) {
+                    icalcomponent *comp = icaltimezone_get_component(zone);
+                    if (comp) {
+                        printf("%s\n", icalcomponent_as_ical_string(comp));
+                    }
+                    zonedef_printed = 1;
+                }
             }
 
             if (curr_failed) {
@@ -140,14 +159,6 @@ int main(int argc, char **argv)
                total_failed,
                total_okay,
 	       percent_failed);
-	if(!percent_failed) {
-	    ret = 0; /* good enough.
-			we will never be perfect unless our builtin
-			zones are created with vzic's -pure option.
-			Even then, we need to be in-sync with the
-			distro tzdata.. not that likely */
-	    printf(" *** There will always be a small error rate comparing builtin to distro timezones *** \n");
-	}
     }
 
     return ret;
